@@ -1,14 +1,17 @@
-use serde_derive::{Deserialize, Serialize};
+use serde::{Deserialize, Serialize};
 use std::convert::From;
 use std::fmt;
+use zeroize::Zeroize;
 
-#[derive(Debug, PartialEq, Eq, Serialize, Deserialize)]
+#[derive(Debug, PartialEq, Eq, Serialize, Deserialize, Zeroize)]
+#[zeroize(drop)]
 pub enum StoreError {
   InvalidBlock(String),
   InvalidStoreUrl(String),
   IO(String),
   Mutex(String),
   Conflict(String),
+  StoreNotFound(String),
 }
 
 impl fmt::Display for StoreError {
@@ -19,6 +22,7 @@ impl fmt::Display for StoreError {
       StoreError::IO(error) => write!(f, "IO: {}", error)?,
       StoreError::Mutex(error) => write!(f, "Internal locking problem: {}", error)?,
       StoreError::Conflict(error) => write!(f, "Conflict: {}", error)?,
+      StoreError::StoreNotFound(name) => write!(f, "Store with name {} not found", name)?,
     }
     Ok(())
   }
