@@ -1,20 +1,17 @@
-#[cfg(all(unix, any(feature = "with_x11", feature = "with_xcb")))]
+#[cfg(all(unix, feature = "with_x11"))]
 mod debounce;
 mod error;
-#[cfg(all(unix, not(any(feature = "with_x11", feature = "with_xcb"))))]
+#[cfg(all(unix, not(feature = "with_x11")))]
 mod unix_none;
 mod unix_x11;
-mod unix_xcb;
 #[cfg(windows)]
 mod windows;
 
 pub use self::error::*;
-#[cfg(all(unix, not(any(feature = "with_x11", feature = "with_xcb"))))]
+#[cfg(all(unix, not(feature = "with_x11")))]
 pub use self::unix_none::Clipboard;
 #[cfg(all(unix, feature = "with_x11"))]
 pub use self::unix_x11::Clipboard;
-#[cfg(all(unix, feature = "with_xcb", not(feature = "with_x11")))]
-pub use self::unix_xcb::Clipboard;
 #[cfg(windows)]
 pub use self::windows::Clipboard;
 
